#!/bin/bash


#setup variables
#set the version of this script
myversion=1.0.1
verbose=off
nflag=off




#define functions first
myecho()
{
	if [ "$verbose" == "on" ]
	then
		echo "$1"
	fi
}

myopen()
{
	if [ "$verbose" == "on" ]
	then
		open "$1"
	fi
}


#output the header info
outputHeader ()
{
	param1=$1 #name of computer
	param2=$2 #output file name
	
	myecho "Inside outputHeader()"
	myecho "my file name is ${tmpFile}....."

	myecho "paramA = [$paramA]"
	myecho "paramB = [$paramB]"

	
	echo "Info for Computer/System Name: [${param1}]" > ${param2}
	echo "Info Date is: " `date` >> ${param2}
	echo "" >> ${param2}

	myecho "Done outputHeader()"
}

#write the ip address info
# param1 = en0 or en1
# param2 = inet0 or inet1
# param3 = ether0 or ether1
outputInfo1()
{
	param0=$0
	param1=$1
	param2=$2
	param3=$3
	
	myecho "Inside outputInfo1()"
	myecho "param0 = [$0]"
	myecho "param1 = [$param1]"	#en0 or en1
	myecho "param2 = [$param2]"	#inet0 or inet1
	myecho "param3 = [$param3]"	#ether0 or ether1
	
	myecho "param1 len = [${#param1}]"
	myecho "param2 len = [${#param2}]"
	myecho "param3 len = [${#param3}]"
	
	
	echo "" >> ${tmpFile}

	len1=$(echo ${#param1})
	len2=$(echo ${#param2})
	len3=$(echo ${#param3})
	
	if [ "$len1" != "0" ]	#compare string
	then
		echo "Info for ${param1}:" >> ${tmpFile}
	fi

	if [ "$len2" != "0" ]	#compare string
	then
		echo "	${param2}" >> ${tmpFile}
	fi

	if [ "$len3" != "0" ]	#compare string
	then
		echo "	${param3}" >> ${tmpFile}
	fi

	myecho "Done with outputInfo1()"
}


appendLocationFile ()
{
	fileToAppend=$1
	outputFile=$2

	#append the location file
	echo "" >> ${outputFile}
	if [ -n "$fileToAppend" ]
	then
		if [ -e "$fileToAppend" ]
		then
			echo "The File (~/${fileToAppend}) Contains:" >> ${outputFile}
			cat "${fileToAppend}" >> ${outputFile}

		else
			echo "The File (~/${fileToAppend}) Does NOT Exist!!!" >> ${outputFile}
			echo "" >> ${outputFile}
			echo "" >> ${outputFile}
		fi

	else
		echo "No Location.txt file passed to script..." >> ${outputFile}
	fi
}


###################################################################################

#evaluate options
filename=
while getopts vnf: opt
do
    case "$opt" in
      v)  verbose=on
			myecho "found opt=v..."
			shift;;
	  n)  nflag=on
			myecho "found opt=n..."
			shift;;
      f)  filename="$OPTARG"
			shift
			shift;;
      \?)		# unknown flag
      	  echo >&2 \
	  "usage: $0 [-v] [-f filename] [file ...]"
	  exit 1;;
    esac
done


#if someone passes -n
# we just want to return the version number back to them
if [ "$nflag" == "on" ]
then 
	echo "version: $myversion"
	exit 0
fi






#get params from commandline
locationTxtFile=$1	#"Documents/Send My IP Script/Location.txt"
tmpFile=$2	#"/text.txt"
totalParams=$#
minParams=2

#make sure we are at the user home directory
cd ~ #go into current user home directory
#open "${locationTxtFile}"


#get params
myecho "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
myecho "Total Params = [$totalParams]"	#name of the script
myecho "Param0 = [$0]"	#name of the script
myecho "Param1 = [$1]"	#path to location.log
myecho "Param2 = [$2]"	#path to tmpfile

if [ "$totalParams" -lt "$minParams" ]
then
	myecho "NOT enough Params... Using Factory Defaults..."
	locationTxtFile="Documents/Send My IP Script/Location.txt"
	tmpFile="/tmp/ifconfigTeps.txt"
else
	myecho "ENOUGH Params.."
fi

myecho "logFile is: [${logFile}]"
myecho "tmpFile is: [${tmpFile}]"




# retrieve the name of this computer
computerName=`/usr/sbin/scutil --get ComputerName`

# get ip info from en0 and en1
inet0=$(echo `/sbin/ifconfig en0 | grep 'inet ' | awk '{print "en0=" $2}'`)
inet1=$(echo `/sbin/ifconfig en1 | grep 'inet ' | awk '{print "en1=" $2}'`)
ether0=$(echo `/sbin/ifconfig en0 | grep 'ether ' | awk '{print "mac0=" $2}'`)
ether1=$(echo `/sbin/ifconfig en1 | grep 'ether ' | awk '{print "mac1=" $2}'`)


# write out the header
outputHeader "$computerName" "$tmpFile" ;

# write out the ip info
outputInfo1 "en0" "$inet0" "$ether0" ;
outputInfo1 "en1" "$inet1" "$ether1" ;

# append the location.txt file
appendLocationFile "$locationTxtFile" "$tmpFile";



myopen ${tmpFile}

myecho "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
myecho ""

#End of Script

exit 0


<<COMMENT


echo "Info for Computer/System Name: [${computerName}]" >> ${tmpFile}
echo "Info Date is: " `date` >> ${tmpFile}

ifconfigInfo0=$(echo `/sbin/ifconfig en0`)
ifconfigInfo1=$(echo `/sbin/ifconfig en1`)
echo "ifconfigInfo0 is ${ifconfigInfo0}"
echo "ifconfigInfo1 is ${ifconfigInfo1}"

echo "inet0 is ${inet0}"
echo "inet1 is ${inet1}"

len0=$(echo ${#inet0})
len1=$(echo ${#inet1})

eth0=$(echo ${#ether0})
eth1=$(echo ${#ether1})


echo "Checking for len0 ($len0)"
echo "" >> ${tmpFile}
echo "en0 info:" >> ${tmpFile}
if [ "$len0" == "0" ] && [ "eth0" == "0" ]	#compare string
then
	echo "	(... no info ...)"
	
else
	echo "echoing en0 info to file: [${tmpFile}] ..."
	echo "	${inet0}" >> ${tmpFile}
	echo "	${ether0}" >> ${tmpFile}
fi

echo "Checking for len1 ($len1)"
echo "" >> ${tmpFile}
echo "en1 info:" >> ${tmpFile}
if [ "$len1" == "0" ] && [ "eth1" == "0" ]	#compare string
then
	echo "	(... no info ...)"
else
	echo "echoing en1 info to file: [${tmpFile}] ..."
	echo "	${inet1}" >> ${tmpFile}
	echo "	${ether1}" >> ${tmpFile}
fi



a=bbb
b=bbb

if [ 0 ]      # zero
then
  echo "0 is true."
else          # Or else ...
  echo "0 is false."
fi            # 0 is true.


decimal=15
octal=15 #017   # = 15 (decimal)
hex=0x0f    # = 15 (decimal)
if [ "$decimal" -eq "$octal" ]
then
  echo "$decimal equals $octal"
else
  echo "$decimal is not equal to $octal"       # 15 is not equal to 017
fi      # Doesn't evaluate within [ single brackets ]!



xyz="sss"
echo "Testing \"-n \$xyz\""
if [ -n "$xyz" ]            # More pedantically correct.
then
  echo "Uninitialized variable is true."
else
  echo "Uninitialized variable is false."
fi            # Uninitialized variable is false.




if [ "${a}" -eq "${b}" ]	#compare integer
then
	echo "$a is EQUAL to $b"
else
	echo "$a is NOT Equal to $b"
fi


if [ "$a" = "$b" ]	#compare string
then
	echo "$a is EQUAL to $b"
else
	echo "$a is NOT Equal to $b"
fi


echo "=============="

COMMENT



exit
